<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=he
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-dev',
	'0_langue' => 'עברית [He]',
	'0_liste' => 'spip-he@rezo.net',
	'0_mainteneur' => 'ניקולא בגלין (nicolas.baguelin@free.fr)',

	// A
	'access_interface_graphique' => 'חזרה לממשק הגראפי השלם',
	'access_mode_texte' => 'הופעת הממשק הטקסטואלי המפושט',
	'admin_debug' => '(debug) תיקון הבאגים',
	'admin_modifier_article' => 'תיקון המאמר',
	'admin_modifier_auteur' => 'תיקון המחבר',
	'admin_modifier_breve' => 'תיקון המבזק',
	'admin_modifier_mot' => 'תיקון מילת המפתח',
	'admin_modifier_rubrique' => 'תיקון המדור',
	'admin_recalculer' => 'רענון הדף',
	'afficher_trad' => 'הצג תרגומים',
	'alerte_maj_impossible' => '<b>אזהרה !</b> עדכון של בסיס הנתונים SQL לגרסה @version@ אין אפשרות, אולי בגלל בעיית זכות הגישה לבסיס הנתונים. אנא צור קשר עם המאכסן שלך.',
	'alerte_modif_info_concourante' => 'אזהרה: מידע כבר נשתנה במקום אחר. הערך הוא עכשיו :',
	'analyse_xml' => 'ניתוח XML',
	'annuler' => 'ביטול',
	'antispam_champ_vide' => 'נא להשאיר מלבן זה ריק :',
	'articles_recents' => 'מאמרים חדשים',
	'avis_archive_incorrect' => 'קובץ הארכיון אינו קובץ SPIP ',
	'avis_archive_invalide' => 'קובץ הארכיון אינו בר תוקף',
	'avis_attention' => 'שים לב!',
	'avis_champ_incorrect_type_objet' => 'שם שדה פסול @name@ לאובייקט מסוג @type@',
	'avis_colonne_inexistante' => 'העמוד @col@ לא נמצא.',
	'avis_erreur' => 'שגיאה: ראה להלן',
	'avis_erreur_connexion' => 'שגיאת חיבור',
	'avis_erreur_cookie' => 'בעיית קוקי',
	'avis_erreur_fonction_contexte' => 'שגיאת תכנות. אי אפשר להפעיל את הפונקציה בהקשר זה.    ',
	'avis_erreur_mysql' => 'שגיאת SQL',
	'avis_erreur_sauvegarde' => 'שגיאה בגיבוי (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'נתקלה בעיה בכניסה לאזור פרטי',

	// B
	'barre_a_accent_grave' => 'הכנסת "A" עם הדגשה         ',
	'barre_aide' => 'השתמש בקיצורים טיפוגרפיים כדי לעדן את המערך',
	'barre_e_accent_aigu' => 'הכנסת "A" עם הדגשה       ',
	'barre_eo' => 'הכנסת האות הלטינית oe',
	'barre_eo_maj' => 'הכנסת E בO',
	'barre_euro' => 'הכנסת הסמל €',
	'barre_gras' => '{{הבלטה}}',
	'barre_guillemets' => '« מרכאות »',
	'barre_guillemets_simples' => '”מרכאות פשוטות',
	'barre_intertitre' => 'הפוך ל {{{בין כותרת}}}',
	'barre_italic' => 'הפוך ל{נטוי}',
	'barre_lien' => 'הפוך לקישור',
	'barre_lien_input' => 'נא לציין את כתובת הקישור בהקלדת הכתובת בצורה http://www.mysite/com או בציון המספר של מאמר מאתר זה.',
	'barre_note' => 'הפוך ל [[Note de bas de page]]',
	'barre_paragraphe' => 'פסקה חדשה',
	'barre_quote' => '<quote>ציטוט הודעה</quote>',
	'bouton_changer' => 'תיקון',
	'bouton_chercher' => 'חיפוש',
	'bouton_choisir' => 'בחר',
	'bouton_download' => 'הורדה', # MODIF
	'bouton_enregistrer' => 'שמור',
	'bouton_radio_desactiver_messagerie_interne' => 'ביטול ההתכתבות הפנימית',
	'bouton_radio_envoi_annonces' => 'שליחת הודעות עורך',
	'bouton_radio_non_envoi_annonces' => 'אל תשלח הודעות',
	'bouton_radio_non_envoi_liste_nouveautes' => 'אל תשלח את רשימת החדשות האחרונה',
	'bouton_recharger_page' => 'רענון הדף',
	'bouton_telecharger' => 'הורדה',
	'bouton_upload' => 'הורדה', # MODIF
	'bouton_valider' => 'אישור',

	// C
	'cal_apresmidi' => 'אחרי הצהריים',
	'cal_jour_entier' => 'יום שלם',
	'cal_matin' => 'בוקר',
	'cal_par_jour' => 'לוח הזמנים לפי היום',
	'cal_par_mois' => 'לוח הזמנים לפי החודש',
	'cal_par_semaine' => 'לוח הזמנים לפי השבוע',
	'choix_couleur_interface' => 'צבע',
	'choix_interface' => 'בחירת ממשק',
	'colonne' => 'עמודה',
	'confirm_changer_statut' => 'לתשומת לבך : בקשת לשנות את הסטטוס של אלמנט זה. האם ברצונך להמשיך ?',
	'correcte' => 'נכון',

	// D
	'date_aujourdhui' => 'היום',
	'date_avant_jc' => 'לפני הספירה הנוצרית',
	'date_dans' => 'תוך @delai@',
	'date_de_mois_1' => '@j@ ב@nommois@',
	'date_de_mois_10' => '@j@ ב@nommois@',
	'date_de_mois_11' => '@j@ ב@nommois@',
	'date_de_mois_12' => '@j@ ב@nommois@',
	'date_de_mois_2' => '@j@ ב@nommois@',
	'date_de_mois_3' => '@j@ ב@nommois@',
	'date_de_mois_4' => '@j@ ב@nommois@',
	'date_de_mois_5' => '@j@ ב@nommois@',
	'date_de_mois_6' => '@j@ ב@nommois@',
	'date_de_mois_7' => '@j@ ב@nommois@',
	'date_de_mois_8' => '@j@ ב@nommois@',
	'date_de_mois_9' => '@j@ ב@nommois@',
	'date_demain' => 'מחר',
	'date_fmt_heures_minutes' => '@h@:@m@',
	'date_fmt_jour_heure' => '@jour@ בשעה @heure@',
	'date_fmt_jour_mois' => '@jour@ ב@nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ ב@nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour_date' => 'ב@nomjour@ @date@',
	'date_heures' => 'שעות',
	'date_hier' => 'אתמול',
	'date_il_y_a' => 'יש @delai@',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'יום ראשון',
	'date_jour_1_abbr' => 'יום א’.',
	'date_jour_1_initiale' => 'א.',
	'date_jour_2' => 'יום שני',
	'date_jour_2_abbr' => 'יום ב’.',
	'date_jour_2_initiale' => 'ב.',
	'date_jour_3' => 'יום שלישי',
	'date_jour_3_abbr' => 'יום ג’.',
	'date_jour_3_initiale' => 'ג.',
	'date_jour_4' => 'יום רביעי',
	'date_jour_4_abbr' => 'יום ד’.',
	'date_jour_4_initiale' => 'ד.',
	'date_jour_5' => 'יום חמישי',
	'date_jour_5_abbr' => 'יום ה’.',
	'date_jour_5_initiale' => 'ה.',
	'date_jour_6' => 'יום שישי',
	'date_jour_6_abbr' => 'יום ו’.',
	'date_jour_6_initiale' => 'ו.',
	'date_jour_7' => 'יום שבת',
	'date_jour_7_abbr' => 'יום ש’.',
	'date_jour_7_initiale' => 'ש.',
	'date_jours' => 'ימים',
	'date_minutes' => 'דקות',
	'date_mois' => 'חודשים',
	'date_mois_1' => 'ינואר',
	'date_mois_10' => 'אוקטובר',
	'date_mois_11' => 'נובמבר',
	'date_mois_12' => 'דצמבר',
	'date_mois_2' => 'פברואר',
	'date_mois_3' => 'מרץ',
	'date_mois_4' => 'אפריל',
	'date_mois_5' => 'מאי',
	'date_mois_6' => 'יוני',
	'date_mois_7' => 'יולי',
	'date_mois_8' => 'אוגוסט',
	'date_mois_9' => 'ספטמבר',
	'date_saison_1' => 'חורף',
	'date_saison_2' => 'אביב',
	'date_saison_3' => 'קיץ',
	'date_saison_4' => 'סתיו',
	'date_secondes' => 'שניות',
	'date_semaines' => 'שבועות',
	'date_un_mois' => 'חודש',
	'date_une_heure' => 'שעה',
	'date_une_minute' => 'דקה',
	'date_une_seconde' => 'שני',
	'date_une_semaine' => 'שבועה',
	'dirs_commencer' => 'כדי להתחיל את ההתקנה',
	'dirs_preliminaire' => 'פרלימינרי : <b>התקנת השגת גישה</b>',
	'dirs_probleme_droits' => 'בעיית הגשת גישה',
	'dirs_repertoires_absents' => '<b>לא נמצאו התיקיות הבאות <ul>@bad_dirs@.</ul> </b>
  <p>סיבה אפשרית לכך אמורה להיות בשימוש אותיות גדולות או קטנות.
  נא לבדוק שאכן גודל האותיות מתאים עם שמופיע 
  למעלה; אם לא, נא לשנות את שמות התיקיות בעזרת הקליינט FTP כדי לתקן את השגיאות
  </p><p>אחרי שנעשה כך, אפשר</p>',
	'dirs_repertoires_suivants' => '<b>התיקיות הבאות לא זוכים לכתיבה: <ul>@bad_dirs@.</ul> </b>

  <p>כדי לשנות את זה, נא לשמש בקליינט FTP כדי לתת זכויות לכל אחת 

  מהתיקיות הללו. הפרוצדורה המדויקת נמצאת במדריך ההתקנה.

  </p><p>אחרי שסיימת פעולה זו, אפשר </p>',
	'double_occurrence' => 'כפול של @balise@',

	// E
	'en_cours' => 'בתוקף',
	'envoi_via_le_site' => 'שליחה דרך האתר',
	'erreur' => 'שגיאה',
	'erreur_balise_non_fermee' => 'התאג האחרון אינו נגמר :',
	'erreur_texte' => 'שגיאות',
	'etape' => 'שלב',

	// F
	'fichier_introuvable' => 'לא נמצא הקובץ @fichier@',
	'form_deja_inscrit' => 'אתה כבר רשום.',
	'form_email_non_valide' => 'כתובת הדוא"ל שלך לא מתאימה.',
	'form_forum_access_refuse' => 'הכניסה לאתר אסורה לך.',
	'form_forum_bonjour' => 'שלום @nom@,',
	'form_forum_email_deja_enregistre' => 'כתובת הדוא"ל הזאת כבר רשומה במערכת, כתוצאה מכך הינך יכול להשתמש בסיסמתך הרגילה.',
	'form_forum_identifiant_mail' => 'המזהה החדש נשלח אליך בדוא"ל.',
	'form_forum_identifiants' => 'פרטים אישיים',
	'form_forum_indiquer_nom_email' => 'רשום כאן את שם וכתובת הדוא"ל. שם התחברות אישי יישלח בדוא"ל בקרוב.',
	'form_forum_login' => ':שם התחברות',
	'form_forum_message_auto' => '(זוהי הודעה ממוחשבת)',
	'form_forum_pass' => 'סיסמה:',
	'form_forum_probleme_mail' => '.בעיית דוא"ל: שם המשתמש לא יכול להישלח',
	'form_forum_voici1' => 'הנה הפרטים שלך כדי להשתתף לחיי האתר
"@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'הנה הפרטים שלך כדי להציע מאמרים על
האתר "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'רשום את כתובת הדוא"ל.',
	'form_indiquer_nom' => 'רשום את שמך.',
	'form_indiquer_nom_site' => 'רשום את שם האתר שלך.',
	'form_pet_deja_enregistre' => 'האתר הזה כבר רשום במערכת',
	'form_pet_signature_pasprise' => 'חתימתך נתקלה בהתעלמות.',
	'form_prop_confirmer_envoi' => 'אשר שליחה',
	'form_prop_description' => 'תיאור/פירוש',
	'form_prop_enregistre' => 'ההצעה שלך נרשמה, היא תופיע ברשת לאחר אישור של מנהלי האתר.',
	'form_prop_envoyer' => 'שלח הודעה',
	'form_prop_indiquer_email' => 'נא רשום כתובת דוא"ל ברת תוקף',
	'form_prop_indiquer_nom_site' => 'נא רשום את שם האתר',
	'form_prop_indiquer_sujet' => 'נא רשום נושא',
	'form_prop_message_envoye' => 'ההודעה נשלחה',
	'form_prop_non_enregistre' => 'ההצעה שלך לא נרשמה',
	'form_prop_sujet' => 'נושא',
	'form_prop_url_site' => 'הכתובת הכללית של האתר', # MODIF
	'forum_non_inscrit' => 'או שאינך רשום במערכת או שהכתובת או הסיסמה שגויים.',
	'forum_par_auteur' => 'מאת @auteur@',
	'forum_titre_erreur' => 'שגיאה...',

	// I
	'ical_texte_rss_articles' => 'הקובץ backend של מאמרי האתר הזה נמצא בכתובת הבאה :',
	'ical_texte_rss_articles2' => 'אפשר למצוא גם קבצים "backend" עבור המאמרים לכל מדור של האתר :',
	'ical_texte_rss_breves' => 'מלבד זאת, ישנו קובץ אשר מכיל את פריטי  המבזקים של האתר. על ידי בחירת מספר מדור, הינך יכול לקבל רק את פריטי המבזקים של המדור הזה.',
	'icone_a_suivre' => 'אתר השיגור',
	'icone_admin_site' => 'ניהול האתר',
	'icone_agenda' => 'יומן',
	'icone_aide_ligne' => 'עזרה',
	'icone_articles' => 'מאמרים',
	'icone_auteurs' => 'מחברים',
	'icone_brouteur' => 'גלישה מהירה',
	'icone_configuration_site' => 'תצורת האתר',
	'icone_configurer_site' => 'עצב את אתרך',
	'icone_creer_nouvel_auteur' => 'צור מחבר חדש',
	'icone_creer_rubrique' => 'צור מדור חדש',
	'icone_creer_sous_rubrique' => 'צור מדור משנה',
	'icone_deconnecter' => 'התנתק',
	'icone_discussions' => 'דיונים',
	'icone_doc_rubrique' => 'מסמכים של המדורים',
	'icone_ecrire_article' => 'כתוב מאמר חדש',
	'icone_edition_site' => 'ערוך אתר',
	'icone_gestion_langues' => 'ניהול שפה',
	'icone_informations_personnelles' => 'מידע אישי',
	'icone_interface_complet' => 'ממשק שלם',
	'icone_interface_simple' => 'ממשק מפושט',
	'icone_maintenance_site' => 'תחזוקת אתר',
	'icone_messagerie_personnelle' => 'התכתבות אישית',
	'icone_repartition_debut' => 'הצג חלוקה מן ההתחלה',
	'icone_rubriques' => 'מדורים',
	'icone_sauver_site' => 'גיבוי האתר',
	'icone_site_entier' => 'האתר כולו',
	'icone_sites_references' => 'אתרים עם מראי מקום',
	'icone_statistiques' => 'סטטיסטיקת האתר',
	'icone_suivi_activite' => 'מעקב אחר פעילות האתר',
	'icone_suivi_actualite' => 'התפתחות האתר',
	'icone_suivi_pettions' => 'מעקב/ניהול עצומות',
	'icone_suivi_revisions' => 'שינוים במאמרים',
	'icone_supprimer_document' => 'מחק מסמך זה',
	'icone_supprimer_image' => 'מחק תמונה זו',
	'icone_tous_articles' => 'כל המאמרים שלך',
	'icone_tous_auteur' => 'כל המחברים',
	'icone_visiter_site' => 'בקר את האתר', # MODIF
	'icone_voir_en_ligne' => 'השקפת אונליין',
	'img_indisponible' => 'תמונה לא נמצאת',
	'impossible' => 'אי אפשר',
	'info_a_suivre' => 'לעיקוב »',
	'info_acces_interdit' => 'גישה אסורה',
	'info_acces_refuse' => '"שלילת גישה"',
	'info_action' => 'פעולה: @action@',
	'info_administrer_rubriques' => 'הינך יכול לנהל מדור זה ואת מדורי המשנה שלו',
	'info_adresse_non_indiquee' => '!אינך ציינת כתובת לבדוק',
	'info_aide' => ':עזרה',
	'info_ajouter_mot' => 'הוסף את מילת המפתח הזו',
	'info_annonce' => 'מודעה',
	'info_annonces_generales' => ':מודעות כלליות',
	'info_article_propose' => 'מאמר טעון',
	'info_article_publie' => 'מאמר פורסם',
	'info_article_redaction' => 'מאמר בהתקדמות',
	'info_article_refuse' => 'מאמר נדחה',
	'info_article_supprime' => 'מאמר נמחק',
	'info_articles' => 'מאמרים',
	'info_articles_a_valider' => 'לתת תוקף למאמרים',
	'info_articles_proposes' => 'מאמרי נטענו',
	'info_auteurs_nombre' => ':(מחבר(ים',
	'info_authentification_ftp' => '.(.אישור (על ידי אף.טי.פי',
	'info_breves_2' => 'מבזקים',
	'info_connexion_refusee' => 'החיבור מסורב',
	'info_contact_developpeur' => '.אנא צור קשר עם המפתח',
	'info_contenance' => ':האתר הזה מכיל',
	'info_contribution' => 'תרומת הפורום', # MODIF
	'info_copyright' => 'תוכנה מופצת בחינם <a href=\'license.txt\'>under GPL license.</a>',
	'info_copyright_doc' => 'למידע נוסף, בקרו באתר זה <a href="@spipnet@">http://www.spip.net/en</a>.', # MODIF
	'info_copyright_gpl' => 'תחת רשיון GPL',
	'info_cours_edition' => 'המאמרים שלך בהתקדמות',
	'info_creer_repertoire' => ':נא צור קובץ או ספרייה אשר נקראת',
	'info_creer_repertoire_2' => 'בתוך מדור משנה <b>@repertoire@</b>, ואחרי כן:',
	'info_creer_vignette' => 'יצירה אוטמטית של הגפנית',
	'info_deplier' => 'להבהיר',
	'info_descriptif_nombre' => ':(תיאור(ים',
	'info_description' => ':תיאור',
	'info_description_2' => ':תיאור',
	'info_dimension' => ':גודל',
	'info_ecire_message_prive' => 'כתוב הודעה אישית',
	'info_email_invalide' => '.כתובת דוא"ל שגויה',
	'info_en_cours_validation' => 'המאמרים שלך בהתקדמות',
	'info_en_ligne' => ':מחוברים לאינטרנט עכשיו',
	'info_envoyer_message_prive' => 'שלח הודעה אישית למחבר זה',
	'info_erreur_requete' => ':שגיאה בשאלה',
	'info_erreur_squelette2' => 'אף מסגרת אינו<b>@fichier@</b> זמין',
	'info_erreur_systeme' => 'System error (errno @errsys@)',
	'info_erreur_systeme2' => 'דיסק קשיח מלא או נזק בבסיס הנתונים. <br />
 <font color=\'red\'>נסה/י <a href=\'@script@\'>תיקון נדבך הנתונים</a>,
 או צור קשר עם המארח שלך.</font>', # MODIF
	'info_fini' => '!גמור',
	'info_format_image' => ':פורמט התמונה משומש ליצירת גפנית @gd_formats@.',
	'info_format_non_defini' => 'פורמט לא ידוע',
	'info_grand_ecran' => 'מסך גדול',
	'info_image_aide' => 'עזרה',
	'info_image_process_titre' => 'שיטה ליצירת הגפניות',
	'info_impossible_lire_page' => '<b>Error!</b> הדף לא יכול להקרא <tt><html>@test_proxy@</html></tt> through the proxy <tt>',
	'info_installation_systeme_publication' => '...התקנת מערכת פרסום',
	'info_installer_documents' => 'אפשר להתקין אוטומטית את כל המסמכים שנמצאים בתיקיה @upload@.',
	'info_installer_ftp' => 'כאחראי, אתה יכול להתקין (על ידי העברת קבצים באינטרנט FTP) קבצים בתיקיה @upload@ להעלות כדי לבחור אותם אחר כך ישירות מכאן.',
	'info_installer_images' => 'JPEG,GIF,PNG אתה יכול להציב תמונות בפורמטים',
	'info_installer_images_dossier' => 'הצב תמונות בתיקיה @upload@ להעלות בשביל שתוכל לבחור אותם כאן.',
	'info_interface_complete' => 'ממשק שלם',
	'info_interface_simple' => 'ממשק פשוט',
	'info_joindre_document_article' => 'אתה יכול לחבר למאמר שלך מסמכים מסוגים',
	'info_joindre_document_rubrique' => 'אתה יכול להוסיף למדור הזה מסמכים מסוג',
	'info_joindre_documents_article' => ':אתה יכול לחבר למאמר שלך מסמכים מסוגים',
	'info_l_article' => 'המאמר',
	'info_la_breve' => 'המבזק',
	'info_la_rubrique' => 'המדור',
	'info_langue_principale' => 'שפת האתר הראשי',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ פיקסלים',
	'info_les_auteurs_1' => 'על ידי @les_auteurs@',
	'info_logo_format_interdit' => 'רק הסימנים בפורמט @formats@ מקובלים',
	'info_logo_max_poids' => 'גודל ההלוגואים צריך להיות פחות מ@maxi@ (this file is @actuel@).',
	'info_mail_fournisseur' => 'you@isp.com',
	'info_message_2' => 'הודעה',
	'info_message_supprime' => 'הודעה נמחקה',
	'info_mise_en_ligne' => ':תאריך של פרסום ברשת',
	'info_modification_parametres_securite' => 'שינוי הפרמטרים של האבטחה',
	'info_mois_courant' => ':במשך החודש',
	'info_mot_cle_ajoute' => 'מילת המפתח הזאת נוספה ל',
	'info_multi_herit' => 'שפת ברירת המחדל',
	'info_multi_langues_soulignees' => '<u>לשפות המודגשות</u> ניתן לקבל תרגום לכל הטקסטים של הממשק. אם תבחר/י בשפות אלו, אלמנטים רבים מהאתר הציבורי (תאריכים, טופסים) לא יתורגמו בדרך אוטומטית. לשפות הלא מודגשות, אלמנטים אלו יופיעו בשפה העיקרית של האתר.', # MODIF
	'info_multilinguisme' => 'רב לשוני',
	'info_nom_non_utilisateurs_connectes' => '.שמך לא נמצא ברשימת המשתמשים המחוברים',
	'info_nom_utilisateurs_connectes' => '.שמך נמצא ברשימת המשתמשים המחוברים',
	'info_nombre_en_ligne' => ':ברשת עכשיו',
	'info_non_resultat' => 'אין תוצאות ל "@cherche_mot@"',
	'info_non_utilisation_messagerie' => '.אינך משתמש בהתכתבות הפנימית של אתר זה',
	'info_nouveau_message' => 'יש לך הודעה חדשה',
	'info_nouveaux_messages' => 'יש לך @total_messages@ הודעות חדשות',
	'info_numero_abbreviation' => 'מס’',
	'info_obligatoire' => 'מידע זה הינו הכרחי',
	'info_pense_bete' => 'תזכיר',
	'info_petit_ecran' => 'מסך קטן',
	'info_petition_close' => 'עצומה נסגרה',
	'info_pixels' => 'פיקסלים',
	'info_plusieurs_mots_trouves' => 'מספר מילות מפתח נמצאו "@cherche_mot@":',
	'info_portfolio_automatique' => ':תיק ממוכן',
	'info_premier_resultat' => '[@debut_limit@ תוצאות ראשונות מתוך @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ תוצאות ראשונות מתוך @total@]',
	'info_propose_1' => '[@nom_site_spip@] טעונים: @titre@',
	'info_propose_2' => 'מאמר מוצע
-----------------',
	'info_propose_3' => 'המאמר "@titre@" נטען לפרסום.',
	'info_propose_4' => 'אתה מוזמן לסקור ולתת את חוות דעתך',
	'info_propose_5' => ':בפורום המקושר לו. זה זמין בכתובת',
	'info_publie_01' => 'המאמר "@titre@" קבל תוקף על ידי @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] פרסומים: @titre@',
	'info_publie_2' => 'מאמר מפורסם
-----------------',
	'info_rechercher' => 'חיפוש',
	'info_rechercher_02' => ':חיפוש',
	'info_remplacer_vignette' => 'החלפת הגפנית שבברירת מחדל ללוגו מותאם :',
	'info_sans_titre_2' => 'ללא כותרת',
	'info_selectionner_fichier' => 'בחירת קובץ בתיקיה @upload@',
	'info_selectionner_fichier_2' => 'בחירת קובץ :',
	'info_supprimer_vignette' => 'מחיקת הגפנית',
	'info_symbole_bleu' => 'הסימן <b>הכחול</b> מציין <b>תזכיר</b> אחד : כלומר הודעה לשימושך האישי.',
	'info_symbole_jaune' => 'הסימן <b>הצהוב</b> מציין <b>מודעה לכל העורכים </b>: כל מנהלן יכול לערוך אותה, וכל העורכים יכולים לראות אותה.',
	'info_symbole_vert' => 'הסמל <b> הירוק</b> מסמל <b>הודעות מוחלפות בין משתמשי </b> האתר.',
	'info_telecharger_nouveau_logo' => 'העלה לוגו חדש:',
	'info_telecharger_ordinateur' => 'העלה מהמחשב שלך:',
	'info_tous_resultats_enregistres' => '[כל התוצאות נרשמו]',
	'info_tout_afficher' => 'הצגת הכל',
	'info_travaux_texte' => 'אתר זה עדיין לא מותקן. נא לחזור מאוחר יותר...',
	'info_travaux_titre' => 'האתר בבניה',
	'info_trop_resultat' => 'יש יותר מדי תוצאות ל"@cherche_mot@"; נא לזקק את חיפושך.',
	'info_utilisation_messagerie_interne' => 'את/ה משתמש/ת את הדואר הפנימי של אתר זה.',
	'info_valider_lien' => 'אישור לקישור זה',
	'info_verifier_image' => ', נא לבדוק שהתמונות הועברו בצורה נכונה.',
	'info_vignette_defaut' => 'ברירת מחדל לגפנית',
	'info_vignette_personnalisee' => 'גפנית מותאמת אישית',
	'info_visite' => 'ביקור:',
	'info_vos_rendez_vous' => 'פגישות עתידיות שלך',
	'infos_vos_pense_bete' => 'התזכירים שלך', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'הצג צלמיות בלבד',
	'lien_afficher_texte_icones' => 'הצג צלמיות וטקסט',
	'lien_afficher_texte_seul' => 'הצג טקסט בלבד',
	'lien_liberer' => 'שחרור',
	'lien_liberer_tous' => 'שחרור מאמרים אלו', # MODIF
	'lien_nouvea_pense_bete' => 'תזכיר חדש',
	'lien_nouveau_message' => 'הודעה חדשה',
	'lien_nouvelle_annonce' => 'מודעה חדשה',
	'lien_petitions' => 'פטיציה',
	'lien_popularite' => 'עממיות: @popularite@%',
	'lien_racine_site' => 'שורש האתר',
	'lien_reessayer' => 'נסה/י שנית',
	'lien_repondre_message' => 'הוספת תגובה להודעה זו',
	'lien_supprimer' => 'מחיקה',
	'lien_tout_afficher' => 'הצג הכל',
	'lien_visite_site' => 'ביקור לאתר זה',
	'lien_visites' => '@visites@ ביקורים',
	'lien_voir_auteur' => 'הצג מחבר',
	'ligne' => 'שורה',
	'login' => 'התחברות',
	'login_acces_prive' => 'כניסה לאיזור פרטי',
	'login_autre_identifiant' => 'חיבור עם שם משתמש אחר',
	'login_cookie_accepte' => 'נא לשים את אופציות הדפדפן שלך כדי שהוא יקבל את העוגיות (לפחות עבור אתר זה).',
	'login_cookie_oblige' => 'כדי להתחבר, הדפדפן צריך לקבל עוגיות.',
	'login_deconnexion_ok' => 'מנותק/ת',
	'login_erreur_pass' => 'סיסמה לא נכונה.',
	'login_espace_prive' => 'איזור פרטי',
	'login_identifiant_inconnu' => 'שם משתמש "@login@" לא ידוע למערכת.',
	'login_login' => 'שם משתמש:',
	'login_login2' => 'שם משתמש (מזהה לחיבור לאתר):', # MODIF
	'login_login_pass_incorrect' => '(שם משתמש או סיסמה לא נכונים).',
	'login_motpasseoublie' => 'שכחת את הסיסמה?',
	'login_non_securise' => 'לתשומת לבך : טופס זה אינו בטוח.
   אם לא ברצונך שהסיסמה שלך תיאחז
   במישהו נמצא ברשת, נא להפעיל את ג’בה-סקריפט
  בדפדפן שלך וגם',
	'login_nouvelle_tentative' => 'נסיון חדש',
	'login_par_ici' => 'את/ה נרשם/מת... דרך זו...',
	'login_pass2' => 'סיסמה :',
	'login_preferez_refuser' => '<b>אם ברצונך לאסר עוגיות </b>, ניתן להתחבר דרך שיטת יבור שונה (פחות בטוחה) :',
	'login_recharger' => 'טעון דף זה מחדש',
	'login_rester_identifie' => 'זכור את שם משתמש שלי לאורך כמה ימים',
	'login_retour_public' => 'חזור לאתר הציבורי',
	'login_retour_site' => 'חזור לאתר הציבורי',
	'login_retoursitepublic' => 'חזור לאתר הציבורי',
	'login_sinscrire' => 'הרשמה',
	'login_test_navigateur' => 'מבחן הדפדפן /חיבור מחדש',
	'login_verifiez_navigateur' => '(בכל זאת נא לבדוק שהדפדפן שלך לא זכר את הסיסמה...)',

	// M
	'masquer_colonne' => 'הסתר עמודה זאת',
	'masquer_trad' => 'הסתר את התרגומים',
	'module_fichiers_langues' => 'קבצי השפות',

	// N
	'navigateur_pas_redirige' => 'אם הדפדפן שלך אינו מכוון לקישור, נא להקליק כאן כדי להמשיך.',
	'numero' => 'מספר',

	// O
	'occurence' => 'מקרה',
	'onglet_affacer_base' => 'מחק נדבך התונים זה',
	'onglet_auteur' => 'המחבר',
	'onglet_contenu_site' => 'תוכן האתר',
	'onglet_evolution_visite_mod' => 'דרגת הביקורים',
	'onglet_fonctions_avances' => 'פונקציות מתקדמות',
	'onglet_informations_personnelles' => 'פרטים אישים',
	'onglet_interactivite' => 'אינטראקטיביות',
	'onglet_messagerie' => 'מערכת דואר',
	'onglet_repartition_rubrique' => 'התפלגות לפי המדור',
	'onglet_save_restaur_base' => 'גיבוי/החזרת נדבך הנתונים',
	'onglet_vider_cache' => 'ריקון המטומן',

	// P
	'pass_choix_pass' => 'נא לבחור סיסמה בשבילך:',
	'pass_erreur' => 'שגיאה',
	'pass_erreur_acces_refuse' => '<b>שגיאה:</b> אינך זוכה להיכנס עוד לאתר.',
	'pass_erreur_code_inconnu' => '<b>שגיאה :</b> קוד זה לא מתאים לאף אחד מהמבקרים בעלי זכות כינסה לאתר.',
	'pass_erreur_non_enregistre' => '<b>שגיאה :</b> הדוא"ל <tt>@email_oubli@</tt> אינו נרשם באתר זה.',
	'pass_erreur_non_valide' => '<b>שגיאה :</b> דוא"ל זה <tt>@email_oubli@</tt> אינו מתאים !',
	'pass_erreur_probleme_technique' => '<b>שגיאה :</b> בגלל בעיה טכנית, אי אפשר לשלוח את הדוא"ל.',
	'pass_espace_prive_bla' => 'האיזור הפרטי באתר זה הינו פתוח
  למבקרים הנרשמים בלבד. אחרי שנרשמת
  ינתן לך לראות מאמרים שעודם בהכנה
  להציע מאמרים חדשים ולהשתתף לכל הפורומים.',
	'pass_forum_bla' => 'ביקשת להשתתף לפורום
  זכוי למבקרים הנרשמים בלבד.',
	'pass_indiquez_cidessous' => 'נא לציין את כתובת הדוא"ל שלך בו
   נרשמת בתהליך ההרשמה 
   תקבל דוא"ל המסביר לך את הפרוצדורה
לקבל שוב את פרטי הכניסה שלך.',
	'pass_mail_passcookie' => '(זו הודעה ממוחשבת)
כדי לקבל שוב את פרטי גישתך לאתר
@nom_site_spip@ (@adresse_site@)

נא להקליק בקישור הבא :

    @sendcookie@

אז ינתן לך לבחור סיסמה חדשה
ולהתחבר שוב לאתר

',
	'pass_mot_oublie' => 'שכחתי את הסיסמה',
	'pass_nouveau_enregistre' => 'הסיסמה החדשה שלך נרשמה.',
	'pass_nouveau_pass' => 'סיסמה חדשה',
	'pass_ok' => 'סיסמה נכונה',
	'pass_oubli_mot' => 'שכיחת הסיסמה',
	'pass_quitter_fenetre' => 'סגור את החלון',
	'pass_rappel_login' => 'לתשומת לבך : שם משתמש שלך הינו « @login@ ».',
	'pass_recevoir_mail' => 'תקבל בקרוב דוא"ל שמסביר לך איך לקבל שוב את כניסתך לאתר.',
	'pass_retour_public' => 'חזרה לאתר הציבורי',
	'pass_rien_a_faire_ici' => 'אין מה לעשות.',
	'pass_vousinscrire' => 'הרשמה לאתר',
	'precedent' => 'קודם',
	'previsualisation' => 'ציפיה מוקדמת',
	'previsualiser' => 'ציפיה מוקדמת',

	// R
	'retour' => 'חזרה',

	// S
	'spip_conforme_dtd' => 'SPIP מחשיבה את המסמך הזה כמתאים ל DOCTYPE   שלה: ',
	'squelette' => 'שלד',
	'squelette_inclus_ligne' => 'שלד כלול, שורה',
	'squelette_ligne' => 'שלד, שורה',
	'stats_visites_et_popularite' => '@visites@ ביקורים ; פופולריות : @popularite@',
	'suivant' => 'הבא',

	// T
	'taille_ko' => '@taille@ KB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ בייטים',
	'texte_actualite_site_1' => 'כשתתרגל/י בממשק, תוכל/י להקליק על «',
	'texte_actualite_site_2' => 'ממשק מלא',
	'texte_actualite_site_3' => '» כדי לפתוח אפשרויות נוספות.',
	'texte_creation_automatique_vignette' => 'יצירת אוטומטית של גפנית לציפיה מוקדמת מופעלת על אתר זה. בהתקנת תמונות בפורמט גדול על ידי טופס זה @gd_formats@, תמונות אלו יולוו בגפניות עם גודל הכי גדול של@taille_preview@ פיקסלים.',
	'texte_documents_associes' => 'המסמכים הבאים קשורים למאמר,
    אבל לא הוכנסו לו ישירות.
    לפי הסדרת הדפים באתר הציבור,
    הם יופיעו כמסמכים מצורפים.',
	'texte_erreur_mise_niveau_base' => 'שגיאה בבסיס הנתונים במשך עדכון הדרגה.
  התמונה <b>@fichier@</b> לא עלתה (article @id_article@).
  נא לזכור כתובת זאת ולנסות שוב את עדכון
  הדרגה, ולבדוק שהתמונות אכן מופיעות
  במאמרים.',
	'texte_erreur_visiteur' => 'אתה מנסה להכנס לשטח פרטי עם LOGIN שאינו מאפשר זאת',
	'texte_inc_auth_1' => 'את/ה מחובר/ת תחת שם
  המשתמש <b>@auth_login@</b>, אבל שם משתמש זה אינו קיים יותר בבסיס הנתונים. 
  נא לנסות',
	'texte_inc_auth_2' => 'להתחבר מחדש',
	'texte_inc_auth_3' => ', יותר טוב אחרי שעזבת והתחלת מחדש
  את הדפדפן שלך.',
	'texte_inc_config' => 'השינוים המבוצעים בדפים אלו משפיעים לא מעט
 על הפעלת האתר. מומלץ לא לנגוע בזה בעוד אינך מתרגל
 להפעלת המערכת SPIP <br /><br /><b>באופן
  כללי, מומלץ מאוד להשאיר 
 למנהל האתר לטפל בדפים אלו.</b>',
	'texte_inc_meta_1' => 'המערכת נתקלה בבעיה במשך כתיבת הקובץ<code>@fichier@</code>. כמנהל האתר, אתה מוזמן',
	'texte_inc_meta_2' => 'לבדוק את הזכויות לכתיבה',
	'texte_inc_meta_3' => 'בתיקיה הבאה <code>@repertoire@</code>',
	'texte_statut_en_cours_redaction' => 'בדרכו לחיבור',
	'texte_statut_poubelle' => 'באשפה',
	'texte_statut_propose_evaluation' => 'מוצע להבחנה',
	'texte_statut_publie' => 'מפורסם',
	'texte_statut_refuse' => 'מסורב',
	'titre_ajouter_mot_cle' => 'הוספת מילת מפתח:',
	'titre_cadre_raccourcis' => 'קיצורי דרך :',
	'titre_changer_couleur_interface' => 'שינוי צבע הממשק',
	'titre_image_admin_article' => 'אתה יכול לנהל מאמר זה',
	'titre_image_administrateur' => 'מנהל',
	'titre_image_aide' => 'עזרה על אלמנט זה',
	'titre_image_auteur_supprime' => 'מחבר נמחק',
	'titre_image_redacteur' => 'כותב ללא כניסה',
	'titre_image_redacteur_02' => 'מחבר',
	'titre_image_visiteur' => 'מבקר',
	'titre_joindre_document' => 'צירוף מסמך',
	'titre_mots_cles' => 'מילות מפתח',
	'titre_probleme_technique' => 'לתשומת לבך : בעיה טכנית (שרת SQL) מונעת כניסה לחלק זה של האתר. תודה על הבנתך.',
	'titre_publier_document' => 'פירסום מסמך במדור זה',
	'titre_signatures_attente' => 'חתימה מחכה לאישור',
	'titre_signatures_confirmees' => 'חתימה מאושרת',
	'titre_statistiques' => 'סטטיסטיקות של האתר',
	'titre_titre_document' => 'כותרת המסמך :',
	'todo' => 'בקרוב',
	'trad_reference' => '(מאמר אסמכתה)', # MODIF

	// Z
	'zbug_balise_b_aval' => 'טאג B מתחת מאוחר מדי במעגל : ',
	'zbug_balise_inexistante' => 'טעות @from@: סימן העריכה @balise@ אינו קיים',
	'zbug_balise_sans_argument' => 'טיעון חסר בסימן העריכה @balise@',
	'zbug_boucle' => 'מעגל',
	'zbug_boucle_recursive_undef' => 'מעגל רקורסיבי לא מוגדר : @nom@',
	'zbug_calcul' => 'חישוב',
	'zbug_champ_hors_boucle' => 'שדה @champ@ בחוץ למעגל',
	'zbug_champ_hors_motif' => 'שדה @champ@ בחוץ למעגל של מוטיב @motif@',
	'zbug_code' => 'קוד',
	'zbug_critere_inconnu' => 'קרויטריון לא ידוע @critere@',
	'zbug_distant_interdit' => 'חיצוני אסור',
	'zbug_doublon_table_sans_cle_primaire' => 'כפל על שולחן ללא מפתח ראשוני אטומי',
	'zbug_doublon_table_sans_index' => 'כפל על השולחן ללא אינדקס',
	'zbug_erreur_boucle_double' => 'BOUCLE@id@: הגדרה כפולה',
	'zbug_erreur_boucle_fermant' => 'BOUCLE@id@ : חסר טאג סוגר',
	'zbug_erreur_boucle_syntaxe' => 'תחביר המעגל לא נכון',
	'zbug_erreur_compilation' => 'טעות קומפילציה',
	'zbug_erreur_execution_page' => 'שגיאת ביצוע של הדף',
	'zbug_erreur_filtre' => 'שגיאה : מסננת « @filtre@ » לא מוגדרת',
	'zbug_erreur_meme_parent' => '{meme_parent} הנו מתאים רק ל מעגלים (FORUMS) או (RUBRIQUES)',
	'zbug_erreur_squelette' => 'שגיאה בשלד',
	'zbug_hors_compilation' => 'מחוץ לקמפילציה',
	'zbug_info_erreur_squelette' => 'שגיאה באתר',
	'zbug_inversion_ordre_inexistant' => 'היפוך של סדר שאינו קיים',
	'zbug_pagination_sans_critere' => '# עריכת עמודים ללא קריטריונים (עריכת עמודים) או מופעלת במעגל חוזר',
	'zbug_parametres_inclus_incorrects' => 'פרמטרים של הכללה לא נכונים : @param@',
	'zbug_profile' => 'זמן חישוב : @time@',
	'zbug_resultat' => 'תוצאה',
	'zbug_serveur_indefini' => 'שרת SQL לא מוגדר',
	'zbug_statistiques' => 'הסטטיסטיקות של בקשות SQL מתויגות לפי משך זמן',
	'zbug_table_inconnue' => 'SQL טבלה « @table@ » לא ידועה',
	'zxml_connus_attributs' => 'תכונות ידועות',
	'zxml_de' => 'מן',
	'zxml_inconnu_attribut' => 'תכונות לא ידועות',
	'zxml_inconnu_balise' => 'סימן עריכה לא ידוע',
	'zxml_inconnu_entite' => 'יישות לא ידועה',
	'zxml_inconnu_id' => 'זיהוי לא ידוע',
	'zxml_mais_de' => 'אולם של',
	'zxml_non_conforme' => 'לא מתאים לסיבה',
	'zxml_non_fils' => 'אינו בן של',
	'zxml_nonvide_balise' => 'סימן עריכה אינו ריק',
	'zxml_obligatoire_attribut' => 'תכונה הכרחית אולם חסרה ב',
	'zxml_succession_fils_incorrecte' => 'רצף של חוטים לא נכון',
	'zxml_survoler' => 'לעלעל על מנת לראות את הנכונים',
	'zxml_valeur_attribut' => 'ערך התכונה',
	'zxml_vide_balise' => 'סימן עריכה ריק',
	'zxml_vu' => 'נראה קודם'
);

?>
